@@ -48,7 +48,7 @@ class FileSystemManager():
                   'gpt': '8300',
                   'label': '-L {labelname}',
                   'msdos': '83',
-                  'ssd': ['ssd', 'discard', 'space_cache'],
+                  'ssd': ['ssd', 'space_cache'],
                   'type': ['hdd', 'usb-hdd'],
                   'compress': None,
                   'compatible': ['btrfs-compress']},
@@ -88,7 +88,7 @@ class FileSystemManager():
                 'label': '-L {labelname}',
                 'msdos': '83',
                 'boot': '-i sparce=0',
-                'ssd': ['discard'],
+                'ssd': [],
                 'compress': None,
                 'type': ['hdd', 'usb-hdd']},
         'btrfs-compress': {'defaultopt': defaultOpt,
@@ -99,7 +99,7 @@ class FileSystemManager():
                   'gpt': '8300',
                   'label': '-L {labelname}',
                   'msdos': '83',
-                  'ssd': ['ssd', 'discard', 'space_cache'],
+                  'ssd': ['ssd', 'space_cache'],
                   'type': ['hdd', 'usb-hdd'],
                   'compatible': ['btrfs']},
         'ext4': {'defaultopt': defaultOpt,
@@ -107,7 +107,17 @@ class FileSystemManager():
                  'formatparam': '{labelparam} {device}',
                  'gpt': '8300',
                  'label': '-L {labelname}',
-                 'ssd': ['discard'],
+                 'ssd': [],
+                 'msdos': '83',
+                 'compress': None,
+                 'type': ['hdd', 'usb-hdd']},
+        'ext4-fast-commit': {'defaultopt': defaultOpt,
+                 'format': '/sbin/mkfs.ext4',
+                 'orig': 'ext4',
+                 'formatparam': '-O fast_commit {labelparam} {device}',
+                 'gpt': '8300',
+                 'label': '-L {labelname}',
+                 'ssd': [],
                  'msdos': '83',
                  'compress': None,
                  'type': ['hdd', 'usb-hdd']},
@@ -146,7 +156,7 @@ class FileSystemManager():
                  'label': '-n {labelname}',
                  'msdos': '0b',
                  'auto': False,
-                 'ssd': ['discard'],
+                 'ssd': [],
                  'compress': None,
                  'type': ['flash']},
         'jfs': {'defaultopt': defaultOpt,
@@ -155,7 +165,7 @@ class FileSystemManager():
                 'gpt': '8300',
                 'label': '-L {labelname}',
                 'msdos': '83',
-                'ssd': ['discard'],
+                'ssd': [],
                 'compress': None,
                 'type': ['hdd', 'usb-hdd']},
 #        'nilfs2': {'defaultopt': defaultOpt,
