@@ -452,7 +452,8 @@ class migrate():
                     os.chmod(homedir, perms)
         users = list(set([x[0] for x in addUsersList] + existsMigrateUsers) - {"root"})
         try:
-            map(createHome, (x for x in self.dataUsers if x[0] in users))
+            # map(createHome, (x for x in self.dataUsers if x[0] in users))
+            [createHome(x) for x in self.dataUsers if x[0] in users]
         except Exception as e:
             raise MigrationError(
                 _("Failed to create the user's home directory"))
